@@ -25,6 +25,7 @@ import java.util.List;
 
 import javax.ejb.CreateException;
 import javax.ejb.FinderException;
+import javax.ejb.RemoveException;
 import javax.management.InstanceNotFoundException;
 import javax.management.MBeanException;
 import javax.management.MalformedObjectNameException;
@@ -41,10 +42,13 @@ import com.clustercontrol.bean.ConfirmConstant;
 import com.clustercontrol.bean.FacilityTargetConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.monitor.ejb.entity.EventLogData;
-import com.clustercontrol.monitor.ejb.entity.EventLogLocal;
-import com.clustercontrol.monitor.ejb.entity.EventLogPK;
-import com.clustercontrol.monitor.ejb.entity.EventLogUtil;
+import com.clustercontrol.notify.monitor.ejb.entity.EventLogData;
+import com.clustercontrol.notify.monitor.ejb.entity.EventLogLocal;
+import com.clustercontrol.notify.monitor.ejb.entity.EventLogPK;
+import com.clustercontrol.notify.monitor.ejb.entity.EventLogUtil;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
+import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
+import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 import com.clustercontrol.util.PropertyUtil;
@@ -54,7 +58,7 @@ import com.clustercontrol.util.apllog.AplLogger;
 /**
  * イベント情報の確認を更新するクラス<BR>
  *
- * @version 1.0.0
+ * @version 3.0.0
  * @since 1.0.0
  */
 public class ModifyEventConfirm {
@@ -126,10 +130,15 @@ public class ModifyEventConfirm {
 				
 				if (event != null) {
 					
-					this.modifyConfirm(event.getMonitorId(), event
-							.getPluginId(), event.getFacilityId(), new Date(
-							event.getOutputDate().getTime()), confirmDate,
-							confirmType, confirmUser);
+					this.modifyConfirm(event.getMonitorId(), 
+							event.getPluginId(), 
+							event.getFacilityId(), 
+							event.getPriority(),
+							event.getGenerationDate(),
+							event.getOutputDate(),
+							confirmDate,
+							confirmType, 
+							confirmUser);
 					
 				}
 			}
@@ -144,6 +153,8 @@ public class ModifyEventConfirm {
 	 * @param monitorId 更新対象の監視項目ID
 	 * @param pluginId 更新対象のプラグインID
 	 * @param facilityId 更新対象のファシリティID
+	 * @param priority 更新対象の重要度
+	 * @param generateDate 更新対象の出力日時
 	 * @param outputDate 更新対象の受信日時
 	 * @param confirmDate 更新対象の確認済み日時
 	 * @param confirmType 確認フラグ（未／済）（更新値）
@@ -157,6 +168,8 @@ public class ModifyEventConfirm {
 	public void modifyConfirm(String monitorId,
 			String pluginId,
 			String facilityId,
+			int priority,
+			Date generateDate,
 			Date outputDate,
 			Date confirmDate,
 			int confirmType,
@@ -181,6 +194,11 @@ public class ModifyEventConfirm {
 					confirmDate = new Date();
 				}
 				event.setConfirmDate(new Timestamp(confirmDate.getTime()));	
+				
+				// 抑制したイベントの抑制テーブルを削除
+				String notifyGroupId = NotifyRelationInfo.createNotifyGroupId(pluginId, monitorId);	// 通知グループIDの作成
+				NotifyControllerLocal notify = NotifyControllerUtil.getLocalHome().create();
+				notify.deleteNotifyInhibitionEvent(notifyGroupId, facilityId, new Timestamp(generateDate.getTime()), priority);
 			}
 			
 			// 確認を実施したユーザを設定
@@ -198,6 +216,10 @@ public class ModifyEventConfirm {
             apllog.put("SYS", "004", args);
 			m_log.debug("modifyConfirm():" + e.getMessage());
 			throw e;
+		} catch (RemoveException e) {
+			m_log.error("modifyConfirm():" + e.getMessage(),e);
+		} catch (CreateException e) {
+			m_log.error("modifyConfirm():" + e.getMessage(),e);
 		}
 	}
 	
