@@ -86,7 +86,8 @@ public class RecordGraphView extends ScopeListBaseView {
      *  コンストラクタ
      */
     public RecordGraphView() {
-        super();
+    	// ノードを含め、INTERNAL, UNREGISTEREDを含めず, TOPICを受信しないスコープツリーとする
+        super(false, false, false, false);
         initialize();
     }
 
