@@ -776,7 +776,7 @@ public class CollectorBean implements EntityBean {
 	 * @throws NamingException 
 	 */
 	private void scheduleJob() throws NamingException {
-		m_log.debug("scheduleJob()  Group : "  + QuartzConstant.GROUP_COLLECT + " : " + collectorID + " : " + intervalSec);
+		m_log.debug("scheduleJob() : Group : "  + QuartzConstant.GROUP_COLLECT + " : " + collectorID + " : " + intervalSec);
 		
 		//JobDetail作成
 		JobDetail job = new JobDetail(
@@ -801,33 +801,73 @@ public class CollectorBean implements EntityBean {
         	String cronString = PollingInterval.parseCronExpression(intervalSec);
 
         	cronString = "10 */10 * * * ? *";
-
+        	
+        	// Quartzのトリガ開始時刻
+        	// collector_profileのstart_dateは登録時のまま変更しない
+        	// 差分をとって計算する場合（最低２回はポーリングを行っている必要がある場合）に合わせて、計算開始時間を１監視間隔分遅らせる
+        	long currentTime = System.currentTimeMillis();
+        	long triggerStartTime = currentTime + intervalSec*1000;
+        	m_log.debug("scheduleJob() : currentTime : " + currentTime + "(" + new Date(currentTime) + ") at " + collectorID);
+        	m_log.debug("scheduleJob() : triggerStartTime : " + triggerStartTime + "(" + new Date(triggerStartTime) + ") at " + collectorID);
+        	
+        	// 収集間隔ごとに、cronStringの生成と、計算ロジックの実行タイミング調整（delayTime）をする
         	if(intervalSec < 60){  // 秒単位の場合(リアルタイム、実績収集)
-				int delayTimeUnder1min = QuartzConstant.getDelayTimeUnder1min();
+    			if(m_log.isDebugEnabled())
+    				m_log.debug("scheduleJob() : intervalSec < 60 at " + collectorID);
+
+        		
+        		int delayTimeUnder1min = QuartzConstant.getDelayTimeUnder1min();
 				cronString = delayTimeUnder1min + "/" + intervalSec + " * * * * ? *";
+	        	m_log.debug("scheduleJob() : delayTimeUnder1min : " + delayTimeUnder1min);
+				
+        		// 定期ポーリングから計算ロジックが走るまでの魔の時間(delayTime)に登録された場合は更にdelayTime分計算開始時間を遅らせる
+        		if ((triggerStartTime/1000 % intervalSec) <= (delayTimeUnder1min)){
+
+    				m_log.debug("scheduleJob() : (triggerStartTime/1000 % intervalSec) = " + (triggerStartTime/1000 % intervalSec));
+
+    				// 更新
+        			triggerStartTime = triggerStartTime + delayTimeUnder1min*1000;
+
+        			m_log.debug("scheduleJob() : update triggerStartTime : triggerStartTime + delayTimeUnder1min = "
+							+ triggerStartTime
+							+ "("
+							+ new Date(triggerStartTime) + ")");
+        		} 
+				
         	} else {
-				int delayTimeOver1min = QuartzConstant.getDelayTimeOver1min();
+    			if(m_log.isDebugEnabled())
+    				m_log.debug("scheduleJob() : intervalSec >= 60 at " + collectorID);
+
+        		int delayTimeOver1min = QuartzConstant.getDelayTimeOver1min();
         		if (60 <= intervalSec && intervalSec < 3600){  // 分単位の場合
 					cronString = delayTimeOver1min + " */" + intervalSec/60 + " * * * ? *";
         		} else if (3600 <= intervalSec){  // 時間単位の場合
         			cronString = delayTimeOver1min + " 0 */" + intervalSec/3600 + " * * ? *"; // ポーリングからdelayTime秒ずらして起動
         		} 
+            	m_log.debug("scheduleJob() : delayTimeOver1min : " + delayTimeOver1min);
         		
-        		// 差分をとって計算する場合（最低２回はポーリングを行っている必要がある場合）に合わせて、計算開始時間を１監視間隔分遅らせる
-        		startTime += intervalSec*1000;
-        		
-        		//m_log.info("*BEFORE* startTime = " + startTime);
         		// 定期ポーリングから計算ロジックが走るまでの魔の時間(delayTime)に登録された場合は更にdelayTime分計算開始時間を遅らせる
-        		if ((startTime/1000 % intervalSec) <= (delayTimeOver1min)){
-        			//m_log.info("*in if 1* startTime = " + startTime);
-        			startTime += delayTimeOver1min*1000;
-        			//m_log.info("*in if 2* startTime = " + startTime);
+        		if ((triggerStartTime/1000 % intervalSec) <= (delayTimeOver1min)){
+
+    				m_log.debug("scheduleJob() : (triggerStartTime/1000 % intervalSec) = " + (triggerStartTime/1000 % intervalSec));
+
+    				// 更新
+        			triggerStartTime = triggerStartTime + delayTimeOver1min*1000;
+        			
+    				m_log.debug("scheduleJob() : update triggerStartTime : triggerStartTime + delayTimeOver1min = "
+							+ triggerStartTime
+							+ "("
+							+ new Date(triggerStartTime) + ")");
         		} 
         	}
 			
 			cronTrigger.setCronExpression(cronString);
-			cronTrigger.setStartTime(new Date(startTime));
+			cronTrigger.setStartTime(new Date(triggerStartTime));
 			cronTrigger.setEndTime(new Date(stopTime));
+			
+			// CronTriggerの設定確認用
+			m_log.debug("scheduleJob() : " + cronTrigger.getExpressionSummary());
+			
 		} catch (ParseException e) {
 			m_log.error(e.getMessage(), e);
 		} catch (IllegalArgumentException e){
@@ -1443,8 +1483,10 @@ public class CollectorBean implements EntityBean {
 	 */
 	public Date getStartDate() {
 		if(startTime != 0){
+			m_log.debug("getStartDate() start with not null: " + collectorID + " " + (new Date(startTime)).toString());
 			return new Date(startTime);
 		} else {
+			m_log.debug("getStartDate() start with null: " + collectorID);
 			return null;
 		}
 	}
@@ -1458,8 +1500,10 @@ public class CollectorBean implements EntityBean {
 	 */
 	public void setStartDate(Date startDate) {
 		if(startDate != null){
+			m_log.debug("setStartDate() start with not null: " + collectorID + " " + (new Date(startTime)).toString());
 			this.startTime = startDate.getTime();
 		} else {
+			m_log.debug("setStartDate() start with null: " + collectorID);
 			this.startTime = 0;
 		}
 	}
@@ -1673,7 +1717,7 @@ public class CollectorBean implements EntityBean {
 		CalculatedDataDAO dao = new CalculatedDataDAO();
 		dao.deleteOverPresave(collectorID, startDate);
 		int count = dao.recountFromDB(collectorID);
-		if(count != 0){
+		if(count > -1){
 			this.setCollectCount(count);
 		}
 	}
